@@ -46,7 +46,6 @@ ENV_CONFS = {
     }
 }
 
-
 ENABLE_SWIFT = p.Config('Enable Swift', 'general', 'cluster',
                         config_type="bool", priority=1,
                         default_value=True, is_optional=True)
@@ -128,6 +127,8 @@ def generate_xml_configs(configs, storage_path, nn_hostname, jt_hostname=None):
                                             '/lib/hadoop/hdfs/namenode'),
         'dfs.data.dir': extract_hadoop_path(storage_path,
                                             '/lib/hadoop/hdfs/datanode'),
+        'dfs.hosts': '/etc/hadoop/dn.incl',
+        'dfs.hosts.exclude': '/etc/hadoop/dn.excl',
     }
 
     if jt_hostname:
@@ -136,7 +137,9 @@ def generate_xml_configs(configs, storage_path, nn_hostname, jt_hostname=None):
             'mapred.system.dir': extract_hadoop_path(storage_path,
                                                      '/mapred/mapredsystem'),
             'mapred.local.dir': extract_hadoop_path(storage_path,
-                                                    '/lib/hadoop/mapred')
+                                                    '/lib/hadoop/mapred'),
+            'mapred.hosts': '/etc/hadoop/tt.incl',
+            'mapred.hosts.exclude': '/etc/hadoop/tt.excl',
         }
         cfg.update(mr_cfg)
 
@@ -145,11 +148,14 @@ def generate_xml_configs(configs, storage_path, nn_hostname, jt_hostname=None):
         cfg[key] = value
 
     # applying swift configs if user enabled it
-    swift_xml_confs = [{}]
+    swift_xml_confs = []
     #TODO(aignatov): should be changed. General configs not only Swift
-    if not ('general' in configs and
-            ENABLE_SWIFT.name in configs['general'] and
-            configs['general'][ENABLE_SWIFT.name] == 'false'):
+    swift_in_config = False
+    if ('general' in configs and
+            ENABLE_SWIFT.name in configs['general']):
+        swift_in_config = True
+    if ((swift_in_config and configs['general'][ENABLE_SWIFT.name]) or
+            (not swift_in_config and ENABLE_SWIFT.default_value)):
         swift_xml_confs = swift.get_swift_configs()
         cfg.update(extract_name_values(swift_xml_confs))
         LOG.info("Swift integration is enabled")
@@ -227,3 +233,12 @@ def extract_name_values(configs):
 
 def extract_hadoop_path(lst, hadoop_dir):
     return ",".join([p + hadoop_dir for p in lst])
+
+
+def determine_cluster_config(cluster, config_name):
+    if config_name in cluster.cluster_configs:
+        cluster.cluster_configs.get(config_name)
+    all_conf = get_plugin_configs()
+    for conf in all_conf:
+        if conf.name == config_name:
+            return conf.default_value
