@@ -14,12 +14,12 @@
 # limitations under the License.
 
 from savanna.openstack.common import log as logging
+from savanna.plugins.general import exceptions as ex
+from savanna.plugins.general import utils
 from savanna.plugins import provisioning as p
 from savanna.plugins.vanilla import config_helper as c_helper
-from savanna.plugins.vanilla import exceptions as ex
 from savanna.plugins.vanilla import run_scripts as run
 from savanna.plugins.vanilla import scaling as sc
-from savanna.plugins.vanilla import utils
 from savanna.utils import crypto
 
 
@@ -59,7 +59,7 @@ class VanillaProvider(p.ProvisioningPluginBase):
     def validate(self, cluster):
         nn_count = sum([ng.count for ng
                         in utils.get_node_groups(cluster, "namenode")])
-        if nn_count is not 1:
+        if nn_count != 1:
             raise ex.NotSingleNameNodeException(nn_count)
 
         jt_count = sum([ng.count for ng
@@ -70,7 +70,7 @@ class VanillaProvider(p.ProvisioningPluginBase):
 
         tt_count = sum([ng.count for ng
                         in utils.get_node_groups(cluster, "tasktracker")])
-        if jt_count is 0 and tt_count > 0:
+        if jt_count == 0 and tt_count > 0:
             raise ex.TaskTrackersWithoutJobTracker()
 
     def update_infra(self, cluster):
