@@ -13,15 +13,17 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import urllib
+
 from savanna import context
 from savanna.db import models as m
 from savanna.db import storage as s
 from savanna.openstack.common import excutils
 from savanna.openstack.common import log as logging
-from savanna.openstack.common import uuidutils
 from savanna.plugins import base as plugin_base
 from savanna.plugins import provisioning
 from savanna.service import instances as i
+from savanna.utils import general as g
 from savanna.utils.openstack import nova
 
 LOG = logging.getLogger(__name__)
@@ -49,10 +51,12 @@ def scale_cluster(cluster_id, data):
 
     try:
         context.model_update(cluster, status='Validating')
+        LOG.info(g.format_cluster_status(cluster))
         plugin.validate_scaling(cluster, to_be_enlarged, additional)
     except Exception:
         with excutils.save_and_reraise_exception():
             context.model_update(cluster, status='Active')
+            LOG.info(g.format_cluster_status(cluster))
 
     # If we are here validation is successful.
     # So let's update bd and to_be_enlarged map:
@@ -61,7 +65,8 @@ def scale_cluster(cluster_id, data):
         to_be_enlarged.update({add_n_g.name: additional[add_n_g]})
     context.model_save(cluster)
 
-    context.spawn(_provision_nodes, cluster_id, to_be_enlarged)
+    context.spawn("cluster-scaling-%s" % cluster_id,
+                  _provision_nodes, cluster_id, to_be_enlarged)
     return cluster
 
 
@@ -72,12 +77,16 @@ def create_cluster(values):
     # validating cluster
     try:
         context.model_update(cluster, status='Validating')
+        LOG.info(g.format_cluster_status(cluster))
         plugin.validate(cluster)
-    except Exception:
+    except Exception as ex:
         with excutils.save_and_reraise_exception():
-            context.model_update(cluster, status='Error')
+            context.model_update(cluster, status='Error',
+                                 status_description=str(ex))
+            LOG.info(g.format_cluster_status(cluster))
 
-    context.spawn(_provision_cluster, cluster.id)
+    context.spawn("cluster-creating-%s" % cluster.id,
+                  _provision_cluster, cluster.id)
 
     return cluster
 
@@ -88,14 +97,17 @@ def _provision_nodes(cluster_id, node_group_names_map):
     plugin = plugin_base.PLUGINS.get_plugin(cluster.plugin_name)
 
     context.model_update(cluster, status='Scaling')
-    instances = i.scale_cluster(cluster, node_group_names_map)
+    LOG.info(g.format_cluster_status(cluster))
+    instances = i.scale_cluster(cluster, node_group_names_map, plugin)
 
     if instances:
         context.model_update(cluster, status='Configuring')
+        LOG.info(g.format_cluster_status(cluster))
         plugin.scale_cluster(cluster, instances)
 
     # cluster is now up and ready
     context.model_update(cluster, status='Active')
+    LOG.info(g.format_cluster_status(cluster))
 
 
 def _provision_cluster(cluster_id):
@@ -104,6 +116,7 @@ def _provision_cluster(cluster_id):
 
     # updating cluster infra
     context.model_update(cluster, status='InfraUpdating')
+    LOG.info(g.format_cluster_status(cluster))
     plugin.update_infra(cluster)
 
     # creating instances and configuring them
@@ -111,14 +124,17 @@ def _provision_cluster(cluster_id):
 
     # configure cluster
     context.model_update(cluster, status='Configuring')
+    LOG.info(g.format_cluster_status(cluster))
     plugin.configure_cluster(cluster)
 
     # starting prepared and configured cluster
     context.model_update(cluster, status='Starting')
+    LOG.info(g.format_cluster_status(cluster))
     plugin.start_cluster(cluster)
 
     # cluster is now up and ready
     context.model_update(cluster, status='Active')
+    LOG.info(g.format_cluster_status(cluster))
 
     return cluster
 
@@ -126,6 +142,7 @@ def _provision_cluster(cluster_id):
 def terminate_cluster(**args):
     cluster = get_cluster(**args)
     context.model_update(cluster, status='Deleting')
+    LOG.info(g.format_cluster_status(cluster))
 
     plugin = plugin_base.PLUGINS.get_plugin(cluster.plugin_name)
     plugin.on_terminate_cluster(cluster)
@@ -174,10 +191,10 @@ def get_plugin(plugin_name, version=None):
         return res
 
 
-def convert_to_cluster_template(plugin_name, version, config_file):
+def convert_to_cluster_template(plugin_name, version, name, config_file):
     plugin = plugin_base.PLUGINS.get_plugin(plugin_name)
     tenant_id = context.current().tenant_id
-    name = uuidutils.generate_uuid()
+    name = urllib.unquote(name)
     ct = m.ClusterTemplate(name, tenant_id, plugin_name, version)
     plugin.convert(ct, config_file)
 
@@ -187,7 +204,7 @@ def convert_to_cluster_template(plugin_name, version, config_file):
 def construct_ngs_for_scaling(additional_node_groups):
     additional = {}
     for ng in additional_node_groups:
-        tmpl_id = ng['node_group_template_id']
+        tmpl_id = ng.get('node_group_template_id')
         count = ng['count']
         if tmpl_id:
             tmpl = get_node_group_template(id=tmpl_id)
